@@ -7,8 +7,9 @@
 # TODO - Words with multiple uppercase letters treated as classes and ignored
 
 import builtins
-import imp
+import importlib
 import subprocess
+import sys
 from xmlrpc import client as xmlrpc_client
 
 from enchant.tokenize import Filter, get_tokenizer, tokenize, unit_tokenize
@@ -177,18 +178,29 @@ class ImportableModuleFilter(Filter):
     """
     def __init__(self, tokenizer):
         super().__init__(tokenizer)
-        self.found_modules = set()
-        self.sought_modules = set()
+        self.found_modules = set(sys.builtin_module_names)
+        self.sought_modules = self.found_modules.copy()
 
     def _skip(self, word):
+        valid_module_name = all(n.isidentifier() for n in word.split('.'))
+        if not valid_module_name:
+            return False
+
         if word not in self.sought_modules:
             self.sought_modules.add(word)
             try:
-                imp.find_module(word)
-            except ImportError:
-                return False
-            self.found_modules.add(word)
-            return True
+                mod = importlib.util.find_spec(word)
+            except Exception as err:
+                # This could be an ImportError, some more detailed
+                # error out of distutils, or something else triggered
+                # by failing to be able to import a parent package to
+                # use the metadata to search for a subpackage.
+                logger.debug(
+                    'find_spec({!r}) failed, invalid module name: {}'.format(
+                        word, err))
+            else:
+                if mod is not None:
+                    self.found_modules.add(word)
         return word in self.found_modules
 
 
